==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectList.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectlist_h
#define objectlist_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_list {
  t_adms _adms;
  char* _datatype;
  int _datatype_isdefault : 1;
  GSList* _item;
  int _item_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_list_getuid (p_list mylist);
win32_interface gboolean adms_list_cmp (p_list mylist,p_list reflist);
win32_interface p_list adms_list_new_1 (char* mydatatype);
#define adms_list_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_list_free(item)\
{\
  free(item->_datatype);\
  free(item);\
}
win32_interface p_adms adms_list_new_impl (p_adms arguments[]);
win32_interface p_list adms_list_impl (void* member);
#define adms_list(member) ((p_list) (member))
#define adms_list_new adms_list_new_1
#define adms_list_isdefault_datatype(list) (adms_list(list)->_datatype_isdefault)
#define adms_list_valueof_datatype(list) (adms_list(list)->_datatype)
#define adms_list_isdefault_item(list) (adms_list(list)->_item_isdefault)
#define adms_list_valueof_item(list) (adms_list(list)->_item)
#define adms_list_valueof_adms(list) ((p_adms)list)
#define adms_list_valueto_datatype(a,b) ((p_list)a)->_datatype=(b)
win32_interface void adms_list_valueto_datatype_impl (p_list mylist,char* _datatype);
#define adms_list_valueto_item(a,b) ((p_list)a)->_item=(b)
win32_interface void adms_list_valueto_item_impl (p_list mylist,GSList* _item);
win32_interface gpointer adms_list_list_item_prepend (p_list mymylist,gpointer mydata);
#endif /* objectlist_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectList.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectlist_h
#define objectlist_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_list {
  t_adms _adms;
  p_quark _datatype;
  int _datatype_isdefault : 1;
  p_slist _item;
  int _item_isdefault : 1;
};
#include <admsObject/objectQuark.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_list_uid (p_list mylist);
win32_interface int adms_list_cmp (p_list mylist,p_list reflist);
win32_interface p_list adms_list_new(p_quark mydatatype);
win32_interface p_adms adms_list_new_impl (p_adms arguments[]);
#define adms_list(member) ((p_list) (member))
#define adms_list_isdefault_datatype(list) (adms_list(list)->_datatype_isdefault)
#define adms_list_valueof_datatype(list) (adms_list(list)->_datatype)
#define adms_list_isdefault_item(list) (adms_list(list)->_item_isdefault)
#define adms_list_valueof_item(list) (adms_list(list)->_item)
#define adms_list_valueof_adms(list) ((p_adms)list)
win32_interface inline void adms_list_valueto_datatype (p_list mylist,p_quark _datatype);
win32_interface inline void adms_list_valueto_item (p_list mylist,p_slist _item);
win32_interface void adms_list_list_item_prepend (p_list mymylist,p_adms myitem);
win32_interface inline void adms_list_free(p_list mylist);
#endif /* objectlist_h */
